@@ -1,33 +1,49 @@
 package MooseX::Types::Base;
-BEGIN {
-  $MooseX::Types::Base::AUTHORITY = 'cpan:PHAYLON';
-}
-{
-  $MooseX::Types::Base::VERSION = '0.38';
-}
-use Moose;
-
 # ABSTRACT: Type library base class
 
+our $VERSION = '0.49';
+
+use Moose;
+
 use Carp::Clan                      qw( ^MooseX::Types );
-use MooseX::Types::Util             qw( filter_tags );
 use Sub::Exporter                   qw( build_exporter );
-use Moose::Util::TypeConstraints;
+use Moose::Util::TypeConstraints    qw( find_type_constraint );
 
 use namespace::autoclean;
 
+#pod =head1 DESCRIPTION
+#pod
+#pod You normally won't need to interact with this class by yourself. It is
+#pod merely a collection of functionality that type libraries need to
+#pod interact with moose and the rest of the L<MooseX::Types> module.
+#pod
+#pod =cut
 
 my $UndefMsg = q{Unable to find type '%s' in library '%s'};
 
+#pod =head1 METHODS
+#pod
+#pod =cut
 
+#pod =head2 import
+#pod
+#pod Provides the import mechanism for your library. See
+#pod L<MooseX::Types/"LIBRARY USAGE"> for syntax details on this.
+#pod
+#pod =cut
 
 sub import {
     my ($class, @args) = @_;
 
     # filter or create options hash for S:E
     my $options = (@args and (ref($args[0]) eq 'HASH')) ? $args[0] : undef;
+
+    # preserve additional options, to ensure types are installed into the type library's namespace
+    my %ex_spec = %{ $options || {} };
+    delete @ex_spec{ qw(-wrapper -into -full) };
+
     unless ($options) {
-        $options = {foo => 23};
+        $options = {};
         unshift @args, $options;
     }
 
@@ -36,10 +52,12 @@ sub import {
 
     # determine the wrapper, -into is supported for compatibility reasons
     my $wrapper = $options->{ -wrapper } || 'MooseX::Types';
+
     $args[0]->{into} = $options->{ -into }
         if exists $options->{ -into };
 
-    my (%ex_spec, %ex_util);
+    my %ex_util;
+
   TYPE:
     for my $type_short (@types) {
 
@@ -58,16 +76,19 @@ sub import {
             };
 
         # the check helper
+        my $check_name = "is_${type_short}";
         push @{ $ex_spec{exports} },
-            "is_${type_short}",
+            $check_name,
             sub { $wrapper->check_export_generator($type_short, $type_full, $undef_msg) };
 
         # only export coercion helper if full (for libraries) or coercion is defined
         next TYPE
             unless $options->{ -full }
             or ($type_cons and $type_cons->has_coercion);
+
+        my $coercion_name = "to_${type_short}";
         push @{ $ex_spec{exports} },
-            "to_${type_short}",
+            $coercion_name,
             sub { $wrapper->coercion_export_generator($type_short, $type_full, $undef_msg) };
         $ex_util{ $type_short }{to}++;  # shortcut to remember this exists
     }
@@ -100,6 +121,11 @@ sub import {
     return $class->$exporter(@new_args);
 }
 
+#pod =head2 get_type
+#pod
+#pod This returns a type from the library's store by its name.
+#pod
+#pod =cut
 
 sub get_type {
     my ($class, $type) = @_;
@@ -112,6 +138,11 @@ sub get_type {
     return $class->type_storage->{ $type };
 }
 
+#pod =head2 type_names
+#pod
+#pod Returns a list of all known types by their name.
+#pod
+#pod =cut
 
 sub type_names {
     my ($class) = @_;
@@ -120,6 +151,11 @@ sub type_names {
     return keys %{ $class->type_storage };
 }
 
+#pod =head2 add_type
+#pod
+#pod Adds a new type to the library.
+#pod
+#pod =cut
 
 sub add_type {
     my ($class, $type) = @_;
@@ -128,6 +164,12 @@ sub add_type {
     $class->type_storage->{ $type } = "${class}::${type}";
 }
 
+#pod =head2 has_type
+#pod
+#pod Returns true or false depending on if this library knows a type by that
+#pod name.
+#pod
+#pod =cut
 
 sub has_type {
     my ($class, $type) = @_;
@@ -136,6 +178,13 @@ sub has_type {
     return ! ! $class->type_storage->{ $type };
 }
 
+#pod =head2 type_storage
+#pod
+#pod Returns the library's type storage hash reference. You shouldn't use this
+#pod method directly unless you know what you are doing. It is not an internal
+#pod method because overriding it makes virtual libraries very easy.
+#pod
+#pod =cut
 
 sub type_storage {
     my ($class) = @_;
@@ -146,6 +195,11 @@ sub type_storage {
     }
 }
 
+#pod =head2 registered_class_types
+#pod
+#pod Returns the class types registered within this library. Don't use directly.
+#pod
+#pod =cut
 
 sub registered_class_types {
     my ($class) = @_;
@@ -156,6 +210,11 @@ sub registered_class_types {
     }
 }
 
+#pod =head2 register_class_type
+#pod
+#pod Register a C<class_type> for use in this library by class name.
+#pod
+#pod =cut
 
 sub register_class_type {
     my ($class, $type) = @_;
@@ -166,6 +225,11 @@ sub register_class_type {
     $class->registered_class_types->{$type->class} = $type;
 }
 
+#pod =head2 get_registered_class_type
+#pod
+#pod Get a C<class_type> registered in this library by name.
+#pod
+#pod =cut
 
 sub get_registered_class_type {
     my ($class, $name) = @_;
@@ -173,6 +237,11 @@ sub get_registered_class_type {
     $class->registered_class_types->{$name};
 }
 
+#pod =head2 registered_role_types
+#pod
+#pod Returns the role types registered within this library. Don't use directly.
+#pod
+#pod =cut
 
 sub registered_role_types {
     my ($class) = @_;
@@ -183,6 +252,11 @@ sub registered_role_types {
     }
 }
 
+#pod =head2 register_role_type
+#pod
+#pod Register a C<role_type> for use in this library by role name.
+#pod
+#pod =cut
 
 sub register_role_type {
     my ($class, $type) = @_;
@@ -193,6 +267,11 @@ sub register_role_type {
     $class->registered_role_types->{$type->role} = $type;
 }
 
+#pod =head2 get_registered_role_type
+#pod
+#pod Get a C<role_type> registered in this library by role name.
+#pod
+#pod =cut
 
 sub get_registered_role_type {
     my ($class, $name) = @_;
@@ -200,6 +279,11 @@ sub get_registered_role_type {
     $class->registered_role_types->{$name};
 }
 
+#pod =head1 SEE ALSO
+#pod
+#pod L<MooseX::Types::Moose>
+#pod
+#pod =cut
 
 1;
 
@@ -207,12 +291,7 @@ __END__
 
 =pod
 
-=encoding utf-8
-
-=for :stopwords Robert "phaylon" Sedlacek Dave Luehrs John Napiorkowski Justin Hunter Karen
-Etheridge Kent Fredric Matt Rolsky S Trout Paul Fenwick Rafael Kitover
-'phaylon' Tomas Florian Doran (t0m) matthewt Ragwitz Graham Knop Hans
-Dieter Pearcey Jesse
+=encoding UTF-8
 
 =head1 NAME
 
@@ -220,7 +299,7 @@ MooseX::Types::Base - Type library base class
 
 =head1 VERSION
 
-version 0.38
+version 0.49
 
 =head1 DESCRIPTION
 
@@ -286,16 +365,22 @@ Get a C<role_type> registered in this library by role name.
 
 L<MooseX::Types::Moose>
 
-=head1 LICENSE
+=head1 SUPPORT
 
-This program is free software; you can redistribute it and/or modify
-it under the same terms as perl itself.
+Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=MooseX-Types>
+(or L<bug-MooseX-Types@rt.cpan.org|mailto:bug-MooseX-Types@rt.cpan.org>).
+
+There is also a mailing list available for users of this distribution, at
+L<http://lists.perl.org/list/moose.html>.
+
+There is also an irc channel available for users of this distribution, at
+L<C<#moose> on C<irc.perl.org>|irc://irc.perl.org/#moose>.
 
 =head1 AUTHOR
 
 Robert "phaylon" Sedlacek <rs@474.at>
 
-=head1 COPYRIGHT AND LICENSE
+=head1 COPYRIGHT AND LICENCE
 
 This software is copyright (c) 2007 by Robert "phaylon" Sedlacek.
 
