@@ -1,14 +1,14 @@
 package MooseX::Types::CheckedUtilExports;
-BEGIN {
-  $MooseX::Types::CheckedUtilExports::AUTHORITY = 'cpan:PHAYLON';
-}
 # ABSTRACT: Wrap L<Moose::Util::TypeConstraints> to be safer for L<MooseX::Types>
-$MooseX::Types::CheckedUtilExports::VERSION = '0.44';
+
+our $VERSION = '0.49';
+
 use strict;
 use warnings;
 use Moose::Util::TypeConstraints ();
 use Moose::Exporter;
-use Carp;
+use Carp 'carp';
+use Sub::Install;
 use namespace::autoclean;
 
 my $StringFoundMsg =
@@ -16,34 +16,39 @@ q{WARNING: String found where Type expected (did you use a => instead of a , ?)}
 
 my @exports = qw/type subtype maybe_type duck_type enum coerce from as/;
 
-# =head1 DESCRIPTION
-#
-# Prevents errors like:
-#
-#     subtype Foo =>
-#     ...
-#
-# Which should be written as:
-#
-#     subtype Foo,
-#     ...
-#
-# When using L<MooseX::Types>. Exported by that module.
-#
-# Exports checked versions of the following subs:
-#
-# C<type> C<subtype> C<maybe_type> C<duck_type> C<enum> C<coerce> C<from> C<as>
-#
-# While C<class_type> and C<role_type> will also register the type in the library.
-#
-# From L<Moose::Util::TypeConstraints>. See that module for syntax.
-#
-# =cut
+#pod =head1 DESCRIPTION
+#pod
+#pod Prevents errors like:
+#pod
+#pod     subtype Foo =>
+#pod     ...
+#pod
+#pod Which should be written as:
+#pod
+#pod     subtype Foo,
+#pod     ...
+#pod
+#pod When using L<MooseX::Types>. Exported by that module.
+#pod
+#pod Exports checked versions of the following subs:
+#pod
+#pod C<type> C<subtype> C<maybe_type> C<duck_type> C<enum> C<coerce> C<from> C<as>
+#pod
+#pod While C<class_type> and C<role_type> will also register the type in the library.
+#pod
+#pod From L<Moose::Util::TypeConstraints>. See that module for syntax.
+#pod
+#pod =for Pod::Coverage class_type role_type
+#pod
+#pod =cut
 
 for my $export (@exports) {
     no strict 'refs';
 
-    *{$export} = sub {
+    Sub::Install::install_sub({
+      into => __PACKAGE__,
+      as   => $export,
+      code => sub {
         my $caller = shift;
 
         local $Carp::CarpLevel = $Carp::CarpLevel + 1;
@@ -55,7 +60,8 @@ for my $export (@exports) {
                 $caller->get_registered_role_type($_[0]);
 
         goto &{"Moose::Util::TypeConstraints::$export"};
-    }
+      }
+    });
 }
 
 Moose::Exporter->setup_import_methods(
@@ -78,11 +84,11 @@ sub role_type ($;$) {
     );
 }
 
-# =head1 SEE ALSO
-#
-# L<MooseX::Types>
-#
-# =cut
+#pod =head1 SEE ALSO
+#pod
+#pod L<MooseX::Types>
+#pod
+#pod =cut
 
 1;
 
@@ -92,15 +98,13 @@ __END__
 
 =encoding UTF-8
 
-=for :stopwords Robert "phaylon" Sedlacek
-
 =head1 NAME
 
 MooseX::Types::CheckedUtilExports - Wrap L<Moose::Util::TypeConstraints> to be safer for L<MooseX::Types>
 
 =head1 VERSION
 
-version 0.44
+version 0.49
 
 =head1 DESCRIPTION
 
@@ -124,15 +128,28 @@ While C<class_type> and C<role_type> will also register the type in the library.
 
 From L<Moose::Util::TypeConstraints>. See that module for syntax.
 
+=for Pod::Coverage class_type role_type
+
 =head1 SEE ALSO
 
 L<MooseX::Types>
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=MooseX-Types>
+(or L<bug-MooseX-Types@rt.cpan.org|mailto:bug-MooseX-Types@rt.cpan.org>).
+
+There is also a mailing list available for users of this distribution, at
+L<http://lists.perl.org/list/moose.html>.
+
+There is also an irc channel available for users of this distribution, at
+L<C<#moose> on C<irc.perl.org>|irc://irc.perl.org/#moose>.
+
 =head1 AUTHOR
 
 Robert "phaylon" Sedlacek <rs@474.at>
 
-=head1 COPYRIGHT AND LICENSE
+=head1 COPYRIGHT AND LICENCE
 
 This software is copyright (c) 2007 by Robert "phaylon" Sedlacek.
 
