@@ -1,31 +1,70 @@
-package MooseX::Types::Moose;
-BEGIN {
-  $MooseX::Types::Moose::AUTHORITY = 'cpan:PHAYLON';
-}
-{
-  $MooseX::Types::Moose::VERSION = '0.38';
-}
-
-# ABSTRACT: Type exports that match the types shipped with L<Moose>
-
 use warnings;
 use strict;
+package MooseX::Types::Moose;
+# ABSTRACT: Type exports that match the types shipped with L<Moose>
+
+our $VERSION = '0.49';
 
 use MooseX::Types;
 use Moose::Util::TypeConstraints ();
 
 use namespace::autoclean;
 
+#pod =head1 SYNOPSIS
+#pod
+#pod   package Foo;
+#pod   use Moose;
+#pod   use MooseX::Types::Moose qw( ArrayRef Int Str );
+#pod   use Carp qw( croak );
+#pod
+#pod   has 'name',
+#pod     is  => 'rw',
+#pod     isa => Str;
+#pod
+#pod   has 'ids',
+#pod     is  => 'rw',
+#pod     isa => ArrayRef[Int];
+#pod
+#pod   sub add {
+#pod       my ($self, $x, $y) = @_;
+#pod       croak 'First arg not an Int'  unless is_Int($x);
+#pod       croak 'Second arg not an Int' unless is_Int($y);
+#pod       return $x + $y;
+#pod   }
+#pod
+#pod   1;
+#pod
+#pod =head1 DESCRIPTION
+#pod
+#pod This package contains a virtual library for L<MooseX::Types> that
+#pod is able to export all types known to L<Moose>. See L<MooseX::Types>
+#pod for general usage information.
+#pod
+#pod =cut
 
 # all available builtin types as short and long name
 my %BuiltIn_Storage
   = map { ($_) x 2 }
     Moose::Util::TypeConstraints->list_all_builtin_type_constraints;
 
+#pod =head1 METHODS
+#pod
+#pod =head2 type_storage
+#pod
+#pod Overrides L<MooseX::Types::Base>' C<type_storage> to provide a hash
+#pod reference containing all built-in L<Moose> types.
+#pod
+#pod =cut
 
 # use prepopulated builtin hash as type storage
 sub type_storage { \%BuiltIn_Storage }
 
+#pod =head1 SEE ALSO
+#pod
+#pod L<Moose>,
+#pod L<Moose::Util::TypeConstraints>
+#pod
+#pod =cut
 
 1;
 
@@ -33,12 +72,7 @@ __END__
 
 =pod
 
-=encoding utf-8
-
-=for :stopwords Robert "phaylon" Sedlacek Dave Luehrs John Napiorkowski Justin Hunter Karen
-Etheridge Kent Fredric Matt Rolsky S Trout Paul Fenwick Rafael Kitover
-'phaylon' Tomas Florian Doran (t0m) matthewt Ragwitz Graham Knop Hans
-Dieter Pearcey Jesse
+=encoding UTF-8
 
 =head1 NAME
 
@@ -46,7 +80,7 @@ MooseX::Types::Moose - Type exports that match the types shipped with L<Moose>
 
 =head1 VERSION
 
-version 0.38
+version 0.49
 
 =head1 SYNOPSIS
 
@@ -87,20 +121,25 @@ reference containing all built-in L<Moose> types.
 
 =head1 SEE ALSO
 
-L<MooseX::Types::Moose>,
 L<Moose>,
 L<Moose::Util::TypeConstraints>
 
-=head1 LICENSE
+=head1 SUPPORT
 
-This program is free software; you can redistribute it and/or modify
-it under the same terms as perl itself.
+Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=MooseX-Types>
+(or L<bug-MooseX-Types@rt.cpan.org|mailto:bug-MooseX-Types@rt.cpan.org>).
+
+There is also a mailing list available for users of this distribution, at
+L<http://lists.perl.org/list/moose.html>.
+
+There is also an irc channel available for users of this distribution, at
+L<C<#moose> on C<irc.perl.org>|irc://irc.perl.org/#moose>.
 
 =head1 AUTHOR
 
 Robert "phaylon" Sedlacek <rs@474.at>
 
-=head1 COPYRIGHT AND LICENSE
+=head1 COPYRIGHT AND LICENCE
 
 This software is copyright (c) 2007 by Robert "phaylon" Sedlacek.
 
